Documentation
¶
Overview ¶
+k8s:deepcopy-gen=package +groupName=ml.llmos.ai
+k8s:deepcopy-gen=package +groupName=ml.llmos.ai
+k8s:deepcopy-gen=package +groupName=ml.llmos.ai
Index ¶
- Variables
- func Kind(kind string) schema.GroupKind
- func Resource(resource string) schema.GroupResource
- type CopyFrom
- type Dataset
- type DatasetCard
- type DatasetList
- type DatasetMetaData
- type DatasetMounting
- type DatasetSpec
- type DatasetStatus
- type DatasetVersion
- type DatasetVersionList
- type DatasetVersionSpec
- type DatasetVersionStatus
- type LocalModel
- type LocalModelList
- type LocalModelSpec
- type LocalModelStatus
- type LocalModelVersion
- type LocalModelVersionList
- type LocalModelVersionSpec
- type LocalModelVersionStatus
- type Model
- type ModelCard
- type ModelList
- type ModelMetaData
- type ModelService
- type ModelServiceList
- type ModelServiceSpec
- type ModelServiceStatus
- type ModelServiceTemplateSpec
- type ModelSpec
- type ModelStatus
- type Notebook
- type NotebookList
- type NotebookSpec
- type NotebookStatus
- type NotebookTemplateSpec
- type Registry
- type RegistryList
- type RegistrySpec
- type RegistryStatus
- type S3Config
- type SnapshottingPhase
- type SnapshottingStatus
- type Version
- type Volume
Constants ¶
This section is empty.
Variables ¶
var ( DatasetResourceName = "datasets" DatasetVersionResourceName = "datasetversions" LocalModelResourceName = "localmodels" LocalModelVersionResourceName = "localmodelversions" ModelResourceName = "models" ModelServiceResourceName = "modelservices" NotebookResourceName = "notebooks" RegistryResourceName = "registries" )
var ( SchemeBuilder = runtime.NewSchemeBuilder(addKnownTypes) AddToScheme = SchemeBuilder.AddToScheme )
var Accessible condition.Cond = "accessible"
var (
Ready condition.Cond = "ready"
)
var SchemeGroupVersion = schema.GroupVersion{Group: ml.GroupName, Version: "v1"}
SchemeGroupVersion is group version used to register these objects
Functions ¶
func Resource ¶
func Resource(resource string) schema.GroupResource
Resource takes an unqualified resource and returns a Group qualified GroupResource
Types ¶
type CopyFrom ¶ added in v0.3.0
type CopyFrom struct {
Namespace string `json:"namespace"`
Dataset string `json:"dataset"`
Version string `json:"version"`
}
func (*CopyFrom) DeepCopy ¶ added in v0.3.0
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CopyFrom.
func (*CopyFrom) DeepCopyInto ¶ added in v0.3.0
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Dataset ¶ added in v0.3.0
type Dataset struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec DatasetSpec `json:"spec,omitempty"`
Status DatasetStatus `json:"status,omitempty"`
}
Dataset is a definition for the LLM Dataset
func NewDataset ¶ added in v0.3.0
func (*Dataset) DeepCopy ¶ added in v0.3.0
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Dataset.
func (*Dataset) DeepCopyInto ¶ added in v0.3.0
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Dataset) DeepCopyObject ¶ added in v0.3.0
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type DatasetCard ¶ added in v0.3.0
type DatasetCard struct {
// +optional
Description string `json:"description,omitempty"`
MetaData DatasetMetaData `json:"metadata"`
}
DatasetCard contains metadata and description for a dataset Reference: https://huggingface.co/docs/datasets/dataset_card
func (*DatasetCard) DeepCopy ¶ added in v0.3.0
func (in *DatasetCard) DeepCopy() *DatasetCard
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DatasetCard.
func (*DatasetCard) DeepCopyInto ¶ added in v0.3.0
func (in *DatasetCard) DeepCopyInto(out *DatasetCard)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type DatasetList ¶ added in v0.3.0
type DatasetList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata"`
Items []Dataset `json:"items"`
}
DatasetList is a list of Dataset resources
func (*DatasetList) DeepCopy ¶ added in v0.3.0
func (in *DatasetList) DeepCopy() *DatasetList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DatasetList.
func (*DatasetList) DeepCopyInto ¶ added in v0.3.0
func (in *DatasetList) DeepCopyInto(out *DatasetList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*DatasetList) DeepCopyObject ¶ added in v0.3.0
func (in *DatasetList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type DatasetMetaData ¶ added in v0.3.0
type DatasetMetaData struct {
Tags []string `json:"tags,omitempty"` // Tags associated with the dataset
License string `json:"license,omitempty"` // License under which the dataset is released
SplitTypes []string `json:"splitTypes,omitempty"` // Types of splits (e.g., train, test, validation)
Features []string `json:"features,omitempty"` // Features included in the dataset
NumSamples int `json:"numSamples,omitempty"` // Total number of samples in the dataset
Language string `json:"language,omitempty"` // Language of the dataset
Citation string `json:"citation,omitempty"` // Citation information for the dataset
Homepage string `json:"homepage,omitempty"` // Homepage of the dataset
DownloadURL string `json:"downloadUrl,omitempty"` // URL to download the dataset
Authors []string `json:"authors,omitempty"` // Authors of the dataset
Contact string `json:"contact,omitempty"` // Contact information for the dataset
}
DatasetMetaData is the metadata of a dataset
func (*DatasetMetaData) DeepCopy ¶ added in v0.3.0
func (in *DatasetMetaData) DeepCopy() *DatasetMetaData
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DatasetMetaData.
func (*DatasetMetaData) DeepCopyInto ¶ added in v0.3.0
func (in *DatasetMetaData) DeepCopyInto(out *DatasetMetaData)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type DatasetMounting ¶ added in v0.3.0
type DatasetMounting struct {
DatasetName string `json:"datasetName"`
Version string `json:"version"`
MountPath string `json:"mountPath"`
}
func (*DatasetMounting) DeepCopy ¶ added in v0.3.0
func (in *DatasetMounting) DeepCopy() *DatasetMounting
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DatasetMounting.
func (*DatasetMounting) DeepCopyInto ¶ added in v0.3.0
func (in *DatasetMounting) DeepCopyInto(out *DatasetMounting)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type DatasetSpec ¶ added in v0.3.0
type DatasetSpec struct {
// +optional
Card *DatasetCard `json:"datasetCard,omitempty"`
Registry string `json:"registry"`
}
DatasetSpec defines the desired state of Dataset
func (*DatasetSpec) DeepCopy ¶ added in v0.3.0
func (in *DatasetSpec) DeepCopy() *DatasetSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DatasetSpec.
func (*DatasetSpec) DeepCopyInto ¶ added in v0.3.0
func (in *DatasetSpec) DeepCopyInto(out *DatasetSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type DatasetStatus ¶ added in v0.3.0
type DatasetStatus struct {
// Conditions is a list of conditions representing the status of the Dataset
Conditions []common.Condition `json:"conditions,omitempty"`
// RootPath is the root path of the dataset in the storage
RootPath string `json:"path,omitempty"`
// Versions is a list of versions of the dataset
Versions []Version `json:"versions,omitempty"`
}
func (*DatasetStatus) DeepCopy ¶ added in v0.3.0
func (in *DatasetStatus) DeepCopy() *DatasetStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DatasetStatus.
func (*DatasetStatus) DeepCopyInto ¶ added in v0.3.0
func (in *DatasetStatus) DeepCopyInto(out *DatasetStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type DatasetVersion ¶ added in v0.3.0
type DatasetVersion struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec DatasetVersionSpec `json:"spec,omitempty"`
Status DatasetVersionStatus `json:"status,omitempty"`
}
DatasetVersion is a definition for the LLM Dataset Version
func NewDatasetVersion ¶ added in v0.3.0
func NewDatasetVersion(namespace, name string, obj DatasetVersion) *DatasetVersion
func (*DatasetVersion) DeepCopy ¶ added in v0.3.0
func (in *DatasetVersion) DeepCopy() *DatasetVersion
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DatasetVersion.
func (*DatasetVersion) DeepCopyInto ¶ added in v0.3.0
func (in *DatasetVersion) DeepCopyInto(out *DatasetVersion)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*DatasetVersion) DeepCopyObject ¶ added in v0.3.0
func (in *DatasetVersion) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type DatasetVersionList ¶ added in v0.3.0
type DatasetVersionList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata"`
Items []DatasetVersion `json:"items"`
}
DatasetVersionList is a list of DatasetVersion resources
func (*DatasetVersionList) DeepCopy ¶ added in v0.3.0
func (in *DatasetVersionList) DeepCopy() *DatasetVersionList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DatasetVersionList.
func (*DatasetVersionList) DeepCopyInto ¶ added in v0.3.0
func (in *DatasetVersionList) DeepCopyInto(out *DatasetVersionList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*DatasetVersionList) DeepCopyObject ¶ added in v0.3.0
func (in *DatasetVersionList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type DatasetVersionSpec ¶ added in v0.3.0
type DatasetVersionSpec struct {
Dataset string `json:"dataset"`
Version string `json:"version"`
// +optional
CopyFrom *CopyFrom `json:"copyFrom,omitempty"`
// +optional
Publish bool `json:"publish"`
}
DatasetVersionSpec defines the desired state of DatasetVersion
func (*DatasetVersionSpec) DeepCopy ¶ added in v0.3.0
func (in *DatasetVersionSpec) DeepCopy() *DatasetVersionSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DatasetVersionSpec.
func (*DatasetVersionSpec) DeepCopyInto ¶ added in v0.3.0
func (in *DatasetVersionSpec) DeepCopyInto(out *DatasetVersionSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type DatasetVersionStatus ¶ added in v0.3.0
type DatasetVersionStatus struct {
Conditions []common.Condition `json:"conditions,omitempty"`
Registry string `json:"registry"`
RootPath string `json:"rootPath"`
// +optional
PublishStatus SnapshottingStatus `json:"publishStatus"`
}
func (*DatasetVersionStatus) DeepCopy ¶ added in v0.3.0
func (in *DatasetVersionStatus) DeepCopy() *DatasetVersionStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DatasetVersionStatus.
func (*DatasetVersionStatus) DeepCopyInto ¶ added in v0.3.0
func (in *DatasetVersionStatus) DeepCopyInto(out *DatasetVersionStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type LocalModel ¶ added in v0.3.0
type LocalModel struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec LocalModelSpec `json:"spec,omitempty"`
Status LocalModelStatus `json:"status,omitempty"`
}
LocalModel is the model stored in the local storage The LocalModel acts as a parent resource for LocalModelVersion instances and provides registry/source information for downloading the model data.
func NewLocalModel ¶ added in v0.3.0
func NewLocalModel(namespace, name string, obj LocalModel) *LocalModel
func (*LocalModel) DeepCopy ¶ added in v0.3.0
func (in *LocalModel) DeepCopy() *LocalModel
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new LocalModel.
func (*LocalModel) DeepCopyInto ¶ added in v0.3.0
func (in *LocalModel) DeepCopyInto(out *LocalModel)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*LocalModel) DeepCopyObject ¶ added in v0.3.0
func (in *LocalModel) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type LocalModelList ¶ added in v0.3.0
type LocalModelList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata"`
Items []LocalModel `json:"items"`
}
LocalModelList is a list of LocalModel resources
func (*LocalModelList) DeepCopy ¶ added in v0.3.0
func (in *LocalModelList) DeepCopy() *LocalModelList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new LocalModelList.
func (*LocalModelList) DeepCopyInto ¶ added in v0.3.0
func (in *LocalModelList) DeepCopyInto(out *LocalModelList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*LocalModelList) DeepCopyObject ¶ added in v0.3.0
func (in *LocalModelList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type LocalModelSpec ¶ added in v0.3.0
type LocalModelSpec struct {
// Registry can be the private registry or the public registry like huggingface.co
Registry string `json:"registry"`
// ModelName is the name of the model in the registry like deepseek-ai/deepseek-r1
ModelName string `json:"modelName"`
// +optional
// DefaultVersion is the default version of the local model
// If DefaultVersion is empty, choose the latest version
DefaultVersion string `json:"defaultVersion"`
}
func (*LocalModelSpec) DeepCopy ¶ added in v0.3.0
func (in *LocalModelSpec) DeepCopy() *LocalModelSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new LocalModelSpec.
func (*LocalModelSpec) DeepCopyInto ¶ added in v0.3.0
func (in *LocalModelSpec) DeepCopyInto(out *LocalModelSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type LocalModelStatus ¶ added in v0.3.0
type LocalModelStatus struct {
// Conditions is a list of conditions representing the status of the Model
Conditions []common.Condition `json:"conditions,omitempty"`
DefaultVersion int `json:"defaultVersion,omitempty"`
DefaultVersionName string `json:"defaultVersionName,omitempty"`
}
func (*LocalModelStatus) DeepCopy ¶ added in v0.3.0
func (in *LocalModelStatus) DeepCopy() *LocalModelStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new LocalModelStatus.
func (*LocalModelStatus) DeepCopyInto ¶ added in v0.3.0
func (in *LocalModelStatus) DeepCopyInto(out *LocalModelStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type LocalModelVersion ¶ added in v0.3.0
type LocalModelVersion struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec LocalModelVersionSpec `json:"spec,omitempty"`
Status LocalModelVersionStatus `json:"status,omitempty"`
}
LocalModelVersion is the version of local model It references its parent LocalModel via the localModel field. The controller will create appropriate PVCs and download jobs to fetch the model contents.
func NewLocalModelVersion ¶ added in v0.3.0
func NewLocalModelVersion(namespace, name string, obj LocalModelVersion) *LocalModelVersion
func (*LocalModelVersion) DeepCopy ¶ added in v0.3.0
func (in *LocalModelVersion) DeepCopy() *LocalModelVersion
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new LocalModelVersion.
func (*LocalModelVersion) DeepCopyInto ¶ added in v0.3.0
func (in *LocalModelVersion) DeepCopyInto(out *LocalModelVersion)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*LocalModelVersion) DeepCopyObject ¶ added in v0.3.0
func (in *LocalModelVersion) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type LocalModelVersionList ¶ added in v0.3.0
type LocalModelVersionList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata"`
Items []LocalModelVersion `json:"items"`
}
LocalModelVersionList is a list of LocalModelVersion resources
func (*LocalModelVersionList) DeepCopy ¶ added in v0.3.0
func (in *LocalModelVersionList) DeepCopy() *LocalModelVersionList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new LocalModelVersionList.
func (*LocalModelVersionList) DeepCopyInto ¶ added in v0.3.0
func (in *LocalModelVersionList) DeepCopyInto(out *LocalModelVersionList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*LocalModelVersionList) DeepCopyObject ¶ added in v0.3.0
func (in *LocalModelVersionList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type LocalModelVersionSpec ¶ added in v0.3.0
type LocalModelVersionSpec struct {
LocalModel string `json:"localModel"`
}
func (*LocalModelVersionSpec) DeepCopy ¶ added in v0.3.0
func (in *LocalModelVersionSpec) DeepCopy() *LocalModelVersionSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new LocalModelVersionSpec.
func (*LocalModelVersionSpec) DeepCopyInto ¶ added in v0.3.0
func (in *LocalModelVersionSpec) DeepCopyInto(out *LocalModelVersionSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type LocalModelVersionStatus ¶ added in v0.3.0
type LocalModelVersionStatus struct {
Version int `json:"version"`
// Conditions is a list of conditions representing the status of the Model
Conditions []common.Condition `json:"conditions,omitempty"`
// +optional
VolumeSnapshot string `json:"volumeSnapshot,omitempty"`
// +optional
SnapshottingStatus SnapshottingStatus `json:"snapshottingStatus,omitempty"`
}
func (*LocalModelVersionStatus) DeepCopy ¶ added in v0.3.0
func (in *LocalModelVersionStatus) DeepCopy() *LocalModelVersionStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new LocalModelVersionStatus.
func (*LocalModelVersionStatus) DeepCopyInto ¶ added in v0.3.0
func (in *LocalModelVersionStatus) DeepCopyInto(out *LocalModelVersionStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Model ¶ added in v0.3.0
type Model struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec ModelSpec `json:"spec,omitempty"`
Status ModelStatus `json:"status,omitempty"`
}
Model is a definition for the LLM Model
func (*Model) DeepCopy ¶ added in v0.3.0
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Model.
func (*Model) DeepCopyInto ¶ added in v0.3.0
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Model) DeepCopyObject ¶ added in v0.3.0
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type ModelCard ¶ added in v0.3.0
type ModelCard struct {
Description string `json:"description"`
MetaData ModelMetaData `json:"metadata"`
}
ModelCard contains metadata and description for a model Reference: https://huggingface.co/docs/hub/models-cards
func (*ModelCard) DeepCopy ¶ added in v0.3.0
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ModelCard.
func (*ModelCard) DeepCopyInto ¶ added in v0.3.0
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ModelList ¶ added in v0.3.0
type ModelList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata"`
Items []Model `json:"items"`
}
ModelList is a list of Model resources
func (*ModelList) DeepCopy ¶ added in v0.3.0
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ModelList.
func (*ModelList) DeepCopyInto ¶ added in v0.3.0
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*ModelList) DeepCopyObject ¶ added in v0.3.0
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type ModelMetaData ¶ added in v0.3.0
type ModelMetaData struct {
Tags []string `json:"tags,omitempty"` // Tags associated with the model
License string `json:"license,omitempty"` // License under which the model is released
Datasets []string `json:"datasets,omitempty"` // Datasets used for training the model
Metrics []string `json:"metrics,omitempty"` // Metrics used for evaluation
Language string `json:"language,omitempty"` // Programming language used in the model
LibraryName string `json:"libraryName,omitempty"` // Name of the library used
LibraryVersion string `json:"libraryVersion,omitempty"` // Version of the library used
CPU bool `json:"cpu,omitempty"` // Whether the model supports CPU
GPU bool `json:"gpu,omitempty"` // Whether the model supports GPU
Framework string `json:"framework,omitempty"` // Framework used for the model
TrainingData string `json:"trainingData,omitempty"` // Description of the training data
EvaluationResults string `json:"evaluationResults,omitempty"` // Results of the model evaluation
BaseModel string `json:"baseModel,omitempty"` // Base model information
}
ModelMetaData is the metadata of a model
func (*ModelMetaData) DeepCopy ¶ added in v0.3.0
func (in *ModelMetaData) DeepCopy() *ModelMetaData
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ModelMetaData.
func (*ModelMetaData) DeepCopyInto ¶ added in v0.3.0
func (in *ModelMetaData) DeepCopyInto(out *ModelMetaData)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ModelService ¶
type ModelService struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec ModelServiceSpec `json:"spec,omitempty"`
Status ModelServiceStatus `json:"status,omitempty"`
}
ModelService is a deployment for the LLM Model
func NewModelService ¶
func NewModelService(namespace, name string, obj ModelService) *ModelService
func (*ModelService) DeepCopy ¶
func (in *ModelService) DeepCopy() *ModelService
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ModelService.
func (*ModelService) DeepCopyInto ¶
func (in *ModelService) DeepCopyInto(out *ModelService)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*ModelService) DeepCopyObject ¶
func (in *ModelService) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type ModelServiceList ¶
type ModelServiceList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata"`
Items []ModelService `json:"items"`
}
ModelServiceList is a list of ModelService resources
func (*ModelServiceList) DeepCopy ¶
func (in *ModelServiceList) DeepCopy() *ModelServiceList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ModelServiceList.
func (*ModelServiceList) DeepCopyInto ¶
func (in *ModelServiceList) DeepCopyInto(out *ModelServiceList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*ModelServiceList) DeepCopyObject ¶
func (in *ModelServiceList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type ModelServiceSpec ¶
type ModelServiceSpec struct {
// +kubebuilder:validation:Enum:={"huggingface","modelscope","local"}
// +kubebuilder:validation:Required
ModelRegistry string `json:"modelRegistry"`
// +kubebuilder:validation:Required
ModelName string `json:"model"`
// +optional, name of the model to serve in API
ServedModelName string `json:"servedModelName,omitempty"`
// +kubebuilder:validation:Required
Replicas int32 `json:"replicas"`
// selector is a label query over pods that should match the replica count.
// It must match the pod template's labels.
// More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/labels/#label-selectors
Selector *metav1.LabelSelector `json:"selector,omitempty"`
// +kubebuilder:default:=ClusterIP
ServiceType corev1.ServiceType `json:"serviceType,omitempty"`
// +optional, list of persistent volume claims
VolumeClaimTemplates []corev1.PersistentVolumeClaim `json:"volumeClaimTemplates,omitempty"`
// +optional, modelService's statefulset update strategy
UpdateStrategy v1.StatefulSetUpdateStrategy `json:"updateStrategy,omitempty"`
// +optional, pod template spec of the model
Template ModelServiceTemplateSpec `json:"template,omitempty"`
// +optional, map of accelerator name to number of accelerators
// e.g., 4090:2 means only schedule to a node with 2 4090 GPUs
// TODO: support accelerators by node selection
Accelerators map[string]uint8 `json:"accelerators,omitempty"`
// +optional, enable gradio GUI of the model
EnableGUI bool `json:"enableGUI,omitempty"`
// +optional, tags of the model
Tags []string `json:"tags,omitempty"`
// +optional, pipeline tag of the model
PipelineTag string `json:"pipelineTag,omitempty"`
// +optional, library name of the model, e.g., transformers, diffusers, etc.
LibraryName string `json:"libraryName,omitempty"`
}
ModelServiceSpec defines the desired state of ModelService
func (*ModelServiceSpec) DeepCopy ¶
func (in *ModelServiceSpec) DeepCopy() *ModelServiceSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ModelServiceSpec.
func (*ModelServiceSpec) DeepCopyInto ¶
func (in *ModelServiceSpec) DeepCopyInto(out *ModelServiceSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ModelServiceStatus ¶
type ModelServiceStatus struct {
Conditions []common.Condition `json:"conditions,omitempty"`
// ReadyReplicas is the number of Pods created by the controller that have a Ready Condition
ReadyReplicas int32 `json:"readyReplicas,omitempty"`
// ContainerState is the mirror state of underlying container
ContainerState corev1.ContainerState `json:"containerState,omitempty"`
// State is the state of the model service
State string `json:"state,omitempty"`
}
ModelServiceStatus defines the observed state of ModelService
func (*ModelServiceStatus) DeepCopy ¶
func (in *ModelServiceStatus) DeepCopy() *ModelServiceStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ModelServiceStatus.
func (*ModelServiceStatus) DeepCopyInto ¶
func (in *ModelServiceStatus) DeepCopyInto(out *ModelServiceStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ModelServiceTemplateSpec ¶
func (*ModelServiceTemplateSpec) DeepCopy ¶
func (in *ModelServiceTemplateSpec) DeepCopy() *ModelServiceTemplateSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ModelServiceTemplateSpec.
func (*ModelServiceTemplateSpec) DeepCopyInto ¶
func (in *ModelServiceTemplateSpec) DeepCopyInto(out *ModelServiceTemplateSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ModelSpec ¶ added in v0.3.0
type ModelSpec struct {
// +optional
Card *ModelCard `json:"modelCard,omitempty"`
Registry string `json:"registry"`
}
ModelSpec defines the desired state of Model
func (*ModelSpec) DeepCopy ¶ added in v0.3.0
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ModelSpec.
func (*ModelSpec) DeepCopyInto ¶ added in v0.3.0
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ModelStatus ¶ added in v0.3.0
type ModelStatus struct {
// Conditions is a list of conditions representing the status of the Model
Conditions []common.Condition `json:"conditions,omitempty"`
// RootPath is the root path of the model in the storage
RootPath string `json:"path,omitempty"`
}
func (*ModelStatus) DeepCopy ¶ added in v0.3.0
func (in *ModelStatus) DeepCopy() *ModelStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ModelStatus.
func (*ModelStatus) DeepCopyInto ¶ added in v0.3.0
func (in *ModelStatus) DeepCopyInto(out *ModelStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Notebook ¶
type Notebook struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec NotebookSpec `json:"spec,omitempty"`
Status NotebookStatus `json:"status,omitempty"`
}
Notebook is the Schema for the notebooks API
func NewNotebook ¶
func (*Notebook) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Notebook.
func (*Notebook) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Notebook) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type NotebookList ¶
type NotebookList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata"`
Items []Notebook `json:"items"`
}
NotebookList is a list of Notebook resources
func (*NotebookList) DeepCopy ¶
func (in *NotebookList) DeepCopy() *NotebookList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new NotebookList.
func (*NotebookList) DeepCopyInto ¶
func (in *NotebookList) DeepCopyInto(out *NotebookList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*NotebookList) DeepCopyObject ¶
func (in *NotebookList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type NotebookSpec ¶
type NotebookSpec struct {
// +optional, template describes the notebooks that will be created.
Template NotebookTemplateSpec `json:"template,omitempty"`
// +kubebuilder:validation:Required
Replicas int32 `json:"replicas"`
// selector is a label query over pods that should match the replica count.
// It must match the pod template's labels.
// More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/labels/#label-selectors
Selector *metav1.LabelSelector `json:"selector,omitempty"`
// +optional, serviceType is the type of service that will be created.
// +kubebuilder:default:=ClusterIP
ServiceType corev1.ServiceType `json:"serviceType,omitempty"`
// +optional, list of PersistentVolumeClaims that will be created.
VolumeClaimTemplates []corev1.PersistentVolumeClaim `json:"volumeClaimTemplates,omitempty"`
// +optional
DatasetMountings []DatasetMounting `json:"datasetMountings,omitempty"`
}
NotebookSpec defines the desired state of Dataset
func (*NotebookSpec) DeepCopy ¶
func (in *NotebookSpec) DeepCopy() *NotebookSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new NotebookSpec.
func (*NotebookSpec) DeepCopyInto ¶
func (in *NotebookSpec) DeepCopyInto(out *NotebookSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type NotebookStatus ¶
type NotebookStatus struct {
// Conditions is an array of current conditions
Conditions []common.Condition `json:"conditions"`
// ReadyReplicas is the number of Pods created by the StatefulSet controller that have a Ready Condition.
ReadyReplicas int32 `json:"readyReplicas"`
// ContainerState is the mirror state of underlying container
ContainerState corev1.ContainerState `json:"containerState,omitempty"`
// State is the state of the notebook
State string `json:"state,omitempty"`
}
NotebookStatus defines the observed state of Dataset
func (*NotebookStatus) DeepCopy ¶
func (in *NotebookStatus) DeepCopy() *NotebookStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new NotebookStatus.
func (*NotebookStatus) DeepCopyInto ¶
func (in *NotebookStatus) DeepCopyInto(out *NotebookStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type NotebookTemplateSpec ¶
func (*NotebookTemplateSpec) DeepCopy ¶
func (in *NotebookTemplateSpec) DeepCopy() *NotebookTemplateSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new NotebookTemplateSpec.
func (*NotebookTemplateSpec) DeepCopyInto ¶
func (in *NotebookTemplateSpec) DeepCopyInto(out *NotebookTemplateSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Registry ¶ added in v0.3.0
type Registry struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec RegistrySpec `json:"spec,omitempty"`
Status RegistryStatus `json:"status,omitempty"`
}
Registry is a cluster-level resource for managing model registries
func NewRegistry ¶ added in v0.3.0
func (*Registry) DeepCopy ¶ added in v0.3.0
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Registry.
func (*Registry) DeepCopyInto ¶ added in v0.3.0
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Registry) DeepCopyObject ¶ added in v0.3.0
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type RegistryList ¶ added in v0.3.0
type RegistryList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata"`
Items []Registry `json:"items"`
}
RegistryList is a list of Registry resources
func (*RegistryList) DeepCopy ¶ added in v0.3.0
func (in *RegistryList) DeepCopy() *RegistryList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new RegistryList.
func (*RegistryList) DeepCopyInto ¶ added in v0.3.0
func (in *RegistryList) DeepCopyInto(out *RegistryList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*RegistryList) DeepCopyObject ¶ added in v0.3.0
func (in *RegistryList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type RegistrySpec ¶ added in v0.3.0
type RegistrySpec struct {
// BackendType is the type of backend storage (e.g., S3)
// +kubebuilder:validation:Enum=S3
BackendType string `json:"backendType"`
// +optional
S3Config S3Config `json:"s3Config,omitempty"`
}
RegistrySpec defines the desired state of Registry
func (*RegistrySpec) DeepCopy ¶ added in v0.3.0
func (in *RegistrySpec) DeepCopy() *RegistrySpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new RegistrySpec.
func (*RegistrySpec) DeepCopyInto ¶ added in v0.3.0
func (in *RegistrySpec) DeepCopyInto(out *RegistrySpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type RegistryStatus ¶ added in v0.3.0
type RegistryStatus struct {
// StorageAddress is the address of the registry where to store models and datasets
StorageAddress string `json:"storageAddress,omitempty"`
// Conditions is a list of conditions representing the status of the Registry
Conditions []common.Condition `json:"conditions,omitempty"`
}
RegistryStatus defines the observed state of Registry
func (*RegistryStatus) DeepCopy ¶ added in v0.3.0
func (in *RegistryStatus) DeepCopy() *RegistryStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new RegistryStatus.
func (*RegistryStatus) DeepCopyInto ¶ added in v0.3.0
func (in *RegistryStatus) DeepCopyInto(out *RegistryStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type S3Config ¶ added in v0.3.0
type S3Config struct {
// UseSSL indicates whether to use http or https
UseSSL bool `json:"useSSL"`
// Endpoint is the endpoint of the S3 storage
Endpoint string `json:"endpoint"`
// Bucket is the name of the S3 bucket
Bucket string `json:"bucket"`
// AccessCredentialSecretName is the name of the secret containing the access credentials
AccessCredentialSecretName string `json:"accessCredentialSecretName"`
}
func (*S3Config) DeepCopy ¶ added in v0.3.0
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new S3Config.
func (*S3Config) DeepCopyInto ¶ added in v0.3.0
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type SnapshottingPhase ¶ added in v0.3.0
type SnapshottingPhase string
const ( SnapshottingPhasePreparePVC SnapshottingPhase = "PreparePVC" SnapshottingPhasePVCReady SnapshottingPhase = "PVCReady" SnapshottingPhaseDownloading SnapshottingPhase = "Downloading" SnapshottingPhaseDownloaded SnapshottingPhase = "Downloaded" SnapshottingPhaseSnapshotting SnapshottingPhase = "Snapshotting" SnapshottingPhaseSnapshotReady SnapshottingPhase = "SnapshotReady" SnapshottingPhaseFailed SnapshottingPhase = "Failed" )
type SnapshottingStatus ¶ added in v0.3.0
type SnapshottingStatus struct {
// +optional
// Phase is the phase of the VolumeSnapshot
Phase SnapshottingPhase `json:"phase,omitempty"`
// +optional
LastTransitionTime metav1.Time `json:"lastTransitionTime"`
// +optional
Message string `json:"message,omitempty"`
// +optional
// SnapshotName is the name of the VolumeSnapshot created for this model version
SnapshotName string `json:"snapshotName,omitempty"`
// +optional
// PVCName is the name of the PVC created for this model version
PVCName string `json:"pvcName,omitempty"`
// +optional
// JobName is the name of the Job created for downloading the model
JobName string `json:"jobName,omitempty"`
}
func (*SnapshottingStatus) DeepCopy ¶ added in v0.3.0
func (in *SnapshottingStatus) DeepCopy() *SnapshottingStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SnapshottingStatus.
func (*SnapshottingStatus) DeepCopyInto ¶ added in v0.3.0
func (in *SnapshottingStatus) DeepCopyInto(out *SnapshottingStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Version ¶ added in v0.3.0
func (*Version) DeepCopy ¶ added in v0.3.0
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Version.
func (*Version) DeepCopyInto ¶ added in v0.3.0
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Volume ¶
type Volume struct {
Name string `json:"name"`
Spec corev1.PersistentVolumeClaimSpec `json:"spec"`
}
func (*Volume) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Volume.
func (*Volume) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.